@@ -100,7 +100,11 @@
 #include <libperfstat.h>
 #endif
 
-#include "process.h"
+#ifdef HAVE_UTMPX_H
+#include <utmpx.h>
+#endif
+
+#include "ProcessTree.h"
 #include "process_sysdep.h"
 
 /**
@@ -132,6 +136,13 @@ boolean_t init_process_info_sysdep(void) {
         systeminfo.mem_max = (uint64_t)mem.real_total * (uint64_t)page_size;
         systeminfo.cpus    = sysconf(_SC_NPROCESSORS_ONLN);
 
+	setutxent();
+	struct utmpx _booted = {.ut_type = BOOT_TIME};
+	struct utmpx *booted = getutxid(&_booted);
+	if (booted)
+		systeminfo.booted = booted->ut_tv.tv_sec;
+	endutxent();
+
         return true;
 }
 
