@@ -62,7 +62,7 @@
 #endif
 
 #include "monit.h"
-#include "process.h"
+#include "ProcessTree.h"
 #include "process_sysdep.h"
 
 
@@ -108,6 +108,17 @@ boolean_t init_process_info_sysdep(void) {
                 return false;
         }
 
+        struct timeval booted;
+        mib[0] = CTL_KERN;
+        mib[1] = KERN_BOOTTIME;
+        len = sizeof(booted);
+        if (sysctl(mib, 2, &booted, &len, NULL, 0) == -1) {
+                DEBUG("system statistics error -- sysctl kern.boottime failed: %s\n", STRERROR);
+                return false;
+        } else {
+                systeminfo.booted = booted.tv_sec;
+        }
+
         return true;
 }
 
