@@ -25,7 +25,7 @@
 #include "config.h"
 
 #include "monit.h"
-#include "process.h"
+#include "ProcessTree.h"
 #include "process_sysdep.h"
 
 
